@@ -1,9 +1,9 @@
 package WebService::Bonusly::Base;
-$WebService::Bonusly::Base::VERSION = '0.160291';
+$WebService::Bonusly::Base::VERSION = '1.000';
 use v5.14;
 use Class::Load qw( load_class );
 use Moose;
-use Furl;
+use LWP::UserAgent;
 
 # ABSTRACT: A utility class for WebService::Bonusly
 
@@ -45,7 +45,11 @@ has debug => (
     default     => 0,
 );
 
-sub _build_ua { Furl->new }
+sub _build_ua {
+    LWP::UserAgent->new(
+        keep_alive => 1,
+    );
+}
 
 sub _service_builder {
     my ($class, $service_name) = @_;
@@ -83,11 +87,11 @@ WebService::Bonusly::Base - A utility class for WebService::Bonusly
 
 =head1 VERSION
 
-version 0.160291
+version 1.000
 
 =head1 DESCRIPTION
 
-This is a utility class for the Bonus.ly web service. 
+This is a utility class for the Bonus.ly web service.
 
 See L<WebService::Bonusly>.
 
