@@ -1,5 +1,5 @@
 package WebService::Bonusly::Service;
-$WebService::Bonusly::Service::VERSION = '0.160291';
+$WebService::Bonusly::Service::VERSION = '1.000';
 use v5.14;
 use Moose;
 use JSON;
@@ -43,15 +43,15 @@ sub _perform_action {
     elsif ($method eq 'POST' || $method eq 'PUT') {
         $path .= '?access_token=' . $self->token unless $tokenless;
         my $content = to_json(\%clean, $self->_json_flags);
-        
+
         $self->print_debug("SEND>> $method $path");
         $self->print_debug("SEND>> Content-Type: application/json");
         $self->print_debug("SEND>> $content");
         if ($method eq 'POST') {
-            $res = $self->ua->post($path, [ 'Content-Type' => 'application/json' ], $content); 
+            $res = $self->ua->post($path, 'Content-Type' => 'application/json', Content => $content);
         }
         else {
-            $res = $self->ua->put($path, [ 'Content-Type' => 'application/json' ], $content);
+            $res = $self->ua->put($path, 'Content-Type' => 'application/json', Content => $content);
         }
     }
     else {
@@ -77,7 +77,7 @@ WebService::Bonusly::Service - A utility class for WebService::Bonusly services
 
 =head1 VERSION
 
-version 0.160291
+version 1.000
 
 =head1 DESCRIPTION
 
